@@ -1,10 +1,11 @@
 use std::convert::TryFrom;
+use std::error::Error;
 
 use crate::models::{Account, HasName, Ledger};
-use crate::{error::Error, CommonOpts};
+use crate::CommonOpts;
 use std::ops::Deref;
 
-pub fn execute(options: &CommonOpts, maybe_ledger: Option<Ledger>) -> Result<(), Error> {
+pub fn execute(options: &CommonOpts, maybe_ledger: Option<Ledger>) -> Result<(), Box<dyn Error>> {
     let ledger = match maybe_ledger {
         Some(ledger) => ledger,
         None => Ledger::try_from(options)?,
