@@ -1,7 +1,7 @@
-use crate::error::LedgerError;
 use crate::models::{Currency, Money};
 use std::collections::hash_map::Iter;
 use std::collections::HashMap;
+use std::error::Error;
 use std::fmt;
 use std::fmt::{Display, Formatter};
 use std::ops::{Add, Neg, Sub};
@@ -12,6 +12,26 @@ use std::rc::Rc;
 pub struct Balance {
     pub balance: HashMap<Option<Rc<Currency>>, Money>,
 }
+impl Default for Balance {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
+#[derive(Debug)]
+pub struct TooManyCurrenciesError {
+    pub num_currencies: usize,
+}
+impl Error for TooManyCurrenciesError {}
+impl Display for TooManyCurrenciesError {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        write!(
+            f,
+            "{} currencies found, expecting only one.",
+            self.num_currencies
+        )
+    }
+}
 
 impl Balance {
     pub fn new() -> Balance {
@@ -22,7 +42,7 @@ impl Balance {
 
     /// Automatic conversion from balance to regular money
     /// it can only be done if the balance has only one currency
-    pub fn to_money(&self) -> Result<Money, LedgerError> {
+    pub fn to_money(&self) -> Result<Money, Box<dyn std::error::Error>> {
         let vec = self
             .balance
             .values()
@@ -31,7 +51,7 @@ impl Balance {
         match vec.len() {
             0 => Ok(Money::Zero),
             1 => Ok(vec[0].clone()),
-            _ => Err(LedgerError::TransactionIsNotBalanced),
+            n => Err(Box::new(TooManyCurrenciesError { num_currencies: n })),
         }
     }
     pub fn is_zero(&self) -> bool {
@@ -57,8 +77,8 @@ impl Balance {
         let mut positive = false;
         let mut negative = false;
         for (_, m) in self.balance.iter() {
-            positive = m.is_positive() | positive;
-            negative = m.is_negative() | negative;
+            positive |= m.is_positive();
+            negative |= m.is_negative();
             if positive & negative {
                 return true;
             }
@@ -68,6 +88,9 @@ impl Balance {
     pub fn len(&self) -> usize {
         self.balance.len()
     }
+    pub fn is_empty(&self) -> bool {
+        self.balance.is_empty()
+    }
     pub fn iter(&self) -> Iter<'_, Option<Rc<Currency>>, Money> {
         self.balance.iter()
     }
