@@ -44,18 +44,20 @@ pub enum PriceType {
 /// Convert from one currency to every other currency
 ///
 /// This uses an implementation of the [Dijkstra algorithm](https://en.wikipedia.org/wiki/Dijkstra%27s_algorithm) to find the shortest path from every
-/// currency to the desired one
+/// currency to the desired one.
+///
+/// The return value is a conversion factor to every other currency
 pub fn conversion(
     currency: Rc<Currency>,
     date: NaiveDate,
-    prices: &Vec<Price>,
+    prices: &[Price],
 ) -> HashMap<Rc<Currency>, BigRational> {
     // Build the graph
     let source = Node {
         currency: currency.clone(),
         date,
     };
-    let mut graph = Graph::from_prices(prices, source.clone());
+    let mut graph = Graph::from_prices(prices, source);
     let mut distances = HashMap::new();
     let mut paths: HashMap<Rc<Node>, Vec<Rc<Edge>>> = HashMap::new();
     let mut queue = vec![];
@@ -169,6 +171,7 @@ impl Edge {
     }
 }
 
+/// A graph
 #[derive(Debug, Clone)]
 struct Graph {
     nodes: Vec<Rc<Node>>,
@@ -177,15 +180,21 @@ struct Graph {
 }
 
 impl Graph {
-    fn from_prices(prices: &Vec<Price>, source: Node) -> Self {
+    /// Build the graph from prices
+    /// every price is a potential connection between two currencies,
+    /// so the prices are actually the edges of the graph
+    fn from_prices(prices: &[Price], source: Node) -> Self {
         let mut nodes = HashMap::new();
         let mut edges = Vec::new();
+
+        // keep the dates for which there is a price
         let mut currency_dates = HashSet::new();
         currency_dates.insert((source.currency.clone(), source.date));
         // Remove redundant prices and create the nodes
         let mut prices_nodup = HashMap::new();
         for p in prices.iter() {
-            if p.date > source.date {
+            // Do not use prices from the future
+            if p.date >= source.date {
                 continue;
             };
             let commodities =
@@ -220,21 +229,18 @@ impl Graph {
         // Create the nodes
         for (c, d) in currency_dates.iter() {
             nodes.insert(
-                (c.clone(), d.clone()),
+                (c.clone(), *d),
                 Rc::new(Node {
                     currency: c.clone(),
-                    date: d.clone(),
+                    date: *d,
                 }),
             );
         }
         // Edges from the prices
         for (_, p) in prices_nodup.iter() {
-            let from = nodes
-                .get(&(p.commodity.clone(), p.date.clone()))
-                .unwrap()
-                .clone();
+            let from = nodes.get(&(p.commodity.clone(), p.date)).unwrap().clone();
             let to = nodes
-                .get(&(p.price.get_commodity().unwrap(), p.date.clone()))
+                .get(&(p.price.get_commodity().unwrap(), p.date))
                 .unwrap()
                 .clone();
             edges.push(Rc::new(Edge {
@@ -306,6 +312,7 @@ mod tests {
     use crate::parser::Tokenizer;
     use crate::CommonOpts;
     use chrono::Utc;
+    use std::convert::TryFrom;
     use std::path::PathBuf;
     use structopt::StructOpt;
 
@@ -313,7 +320,7 @@ mod tests {
     fn test_graph() {
         // Copy from balance command
         let path = PathBuf::from("tests/example_files/demo.ledger");
-        let mut tokenizer = Tokenizer::from(&path);
+        let mut tokenizer = Tokenizer::try_from(&path).unwrap();
         let options = CommonOpts::from_iter(["", "-f", ""].iter());
         let items = tokenizer.tokenize(&options);
         let ledger = items.to_ledger(&options).unwrap();
