@@ -7,9 +7,11 @@
 //! - Directive commodity
 
 use std::collections::HashSet;
+use std::convert::TryFrom;
 use std::fs::read_to_string;
 use std::path::PathBuf;
 
+use crate::error::MissingFileError;
 use crate::models::{Account, Comment, Currency, HasName, Payee, Transaction};
 use crate::parser::utils::count_decimals;
 use crate::{models, CommonOpts, List};
@@ -39,6 +41,11 @@ pub struct ParsedLedger {
     pub files: Vec<PathBuf>,
 }
 
+impl Default for ParsedLedger {
+    fn default() -> Self {
+        ParsedLedger::new()
+    }
+}
 impl ParsedLedger {
     pub fn new() -> Self {
         ParsedLedger {
@@ -72,6 +79,9 @@ impl ParsedLedger {
             + self.comments.len()
             + self.tags.len()
     }
+    pub fn is_empty(&self) -> bool {
+        self.len() == 0
+    }
 }
 
 /// A struct for holding data about the string being parsed
@@ -82,21 +92,25 @@ pub struct Tokenizer<'a> {
     seen_files: HashSet<&'a PathBuf>,
 }
 
-impl<'a> From<&'a PathBuf> for Tokenizer<'a> {
-    fn from(file: &'a PathBuf) -> Self {
+impl<'a> TryFrom<&'a PathBuf> for Tokenizer<'a> {
+    type Error = Box<dyn std::error::Error>;
+    fn try_from(file: &'a PathBuf) -> Result<Self, Self::Error> {
         match read_to_string(file) {
             Ok(content) => {
                 let mut seen_files: HashSet<&PathBuf> = HashSet::new();
                 seen_files.insert(file);
-                Tokenizer {
+                Ok(Tokenizer {
                     file: Some(file),
                     content,
                     seen_files,
-                }
-            }
-            Err(err) => {
-                panic!("{:?}", err);
+                })
             }
+            Err(err) => match err.kind() {
+                std::io::ErrorKind::NotFound => Err(Box::new(
+                    MissingFileError::JournalFileDoesNotExistError(file.to_path_buf()),
+                )),
+                _ => Err(Box::new(err)),
+            },
         }
     }
 }
@@ -123,17 +137,16 @@ impl<'a> Tokenizer<'a> {
         defined_currencies: Option<&List<Currency>>,
     ) -> ParsedLedger {
         let mut ledger: ParsedLedger = ParsedLedger::new();
-        match defined_currencies {
-            Some(x) => ledger.commodities.append(x),
-            None => (),
+        if let Some(x) = defined_currencies {
+            ledger.commodities.append(x);
         }
         if let Some(file) = self.file {
             ledger.files.push(file.clone());
         }
         match GrammarParser::parse(Rule::journal, self.content.as_str()) {
             Ok(mut parsed) => {
-                let mut elements = parsed.next().unwrap().into_inner();
-                while let Some(element) = elements.next() {
+                let elements = parsed.next().unwrap().into_inner();
+                for element in elements {
                     match element.as_rule() {
                         Rule::directive => {
                             let inner = element.into_inner().next().unwrap();
@@ -141,7 +154,7 @@ impl<'a> Tokenizer<'a> {
                                 Rule::include => {
                                     // This is the special case
                                     let mut new_ledger =
-                                        self.include(inner, &options, &ledger.commodities);
+                                        self.include(inner, options, &ledger.commodities).unwrap();
                                     ledger.append(&mut new_ledger);
                                 }
                                 Rule::price => {
@@ -153,7 +166,7 @@ impl<'a> Tokenizer<'a> {
                                 Rule::commodity => {
                                     let commodity = self.parse_commodity(inner);
                                     if let Ok(old_commodity) =
-                                        ledger.commodities.get(&commodity.get_name())
+                                        ledger.commodities.get(commodity.get_name())
                                     {
                                         commodity.update_precision(old_commodity.get_precision());
                                     }
